[vte] [ring] Rename vtecellattr to VteCellAttr



commit d77e97e9cff572ba0e325335dd4a5654676bc5fb
Author: Behdad Esfahbod <behdad behdad org>
Date:   Wed Sep 9 21:10:33 2009 -0400

    [ring] Rename vtecellattr to VteCellAttr

 src/ring.h |   10 +++++-----
 src/vte.c  |    2 +-
 2 files changed, 6 insertions(+), 6 deletions(-)
---
diff --git a/src/vte.c b/src/vte.c
index f2e8870..b618cf6 100644
--- a/src/vte.c
+++ b/src/vte.c
@@ -2923,7 +2923,7 @@ gboolean
 _vte_terminal_insert_char(VteTerminal *terminal, gunichar c,
 			 gboolean insert, gboolean invalidate_now)
 {
-	vtecellattr attr;
+	VteCellAttr attr;
 	VteRowData *row;
 	long col;
 	int columns, i;



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/ring.h b/src/ring.h
index 02389e2..aa003ad 100644
--- a/src/ring.h
+++ b/src/ring.h
@@ -39,13 +39,13 @@ G_BEGIN_DECLS
 
 
 /*
  * vtecellattr: A single cell style attributes
  *
  * Ordered by most commonly changed attributes, to
  * optimize the compact representation.
  */
 
-typedef struct _vtecellattr {
+typedef struct _VteCellAttr {
 	guint32 fragment: 1;	/* A continuation cell. */
 	guint32 columns: 4;	/* Number of visible columns
 				   (as determined by g_unicode_iswide(c)).
@@ -70,8 +70,8 @@ typedef struct _vtecellattr {
 	 */
 
 	/* 30 bits */
-} vtecellattr;
-ASSERT_STATIC (sizeof (vtecellattr) == 4);
+} VteCellAttr;
+ASSERT_STATIC (sizeof (VteCellAttr) == 4);
 
 
 /*
@@ -80,7 +80,7 @@ ASSERT_STATIC (sizeof (vtecellattr) == 4);
 
 typedef struct _VteCell {
 	vteunistr c;
-	vtecellattr attr;
+	VteCellAttr attr;
 } VteCell;
 ASSERT_STATIC (sizeof (VteCell) == 8);
 
@@ -39,13 +39,13 @@ G_BEGIN_DECLS
 
 /*
- * vtecellattr: A single cell style attributes
+ * VteCellAttr: A single cell style attributes
  *
  * Ordered by most commonly changed attributes, to